from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptationsets_api import AdaptationsetsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.subtitle.subtitle_api import SubtitleApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.contentprotection.contentprotection_api import ContentprotectionApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.progressive_webm.progressive_webm_api import ProgressiveWebmApi


class RepresentationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RepresentationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vtt = VttApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.fmp4 = Fmp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.chunked_text = ChunkedTextApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cmaf = CmafApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp4 = Mp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.webm = WebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.progressive_webm = ProgressiveWebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.output import Output
import pprint
import six


class AzureOutput(Output):
    @poscheck_model
    def __init__(self,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 id_=None,
                 acl=None,
                 account_name=None,
                 account_key=None,
                 container=None):
        # type: (string_types, string_types, datetime, datetime, dict, string_types, list[AclEntry], string_types, string_types, string_types) -> None
        super(AzureOutput, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_, acl=acl)

        self._account_name = None
        self._account_key = None
        self._container = None
        self.discriminator = None

        if account_name is not None:
            self.account_name = account_name
        if account_key is not None:
            self.account_key = account_key
        if container is not None:
            self.container = container

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AzureOutput, self), 'openapi_types'):
            types = getattr(super(AzureOutput, self), 'openapi_types')

        types.update({
            'account_name': 'string_types',
            'account_key': 'string_types',
            'container': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AzureOutput, self), 'attribute_map'):
            attributes = getattr(super(AzureOutput, self), 'attribute_map')

        attributes.update({
            'account_name': 'accountName',
            'account_key': 'accountKey',
            'container': 'container'
        })
        return attributes

    @property
    def account_name(self):
        # type: () -> string_types
        """Gets the account_name of this AzureOutput.

        Azure Account Name (required)

        :return: The account_name of this AzureOutput.
        :rtype: string_types
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        # type: (string_types) -> None
        """Sets the account_name of this AzureOutput.

        Azure Account Name (required)

        :param account_name: The account_name of this AzureOutput.
        :type: string_types
        """

        if account_name is not None:
            if not isinstance(account_name, string_types):
                raise TypeError("Invalid type for `account_name`, type has to be `string_types`")

        self._account_name = account_name

    @property
    def account_key(self):
        # type: () -> string_types
        """Gets the account_key of this AzureOutput.

        Azure Account Key (required)

        :return: The account_key of this AzureOutput.
        :rtype: string_types
        """
        return self._account_key

    @account_key.setter
    def account_key(self, account_key):
        # type: (string_types) -> None
        """Sets the account_key of this AzureOutput.

        Azure Account Key (required)

        :param account_key: The account_key of this AzureOutput.
        :type: string_types
        """

        if account_key is not None:
            if not isinstance(account_key, string_types):
                raise TypeError("Invalid type for `account_key`, type has to be `string_types`")

        self._account_key = account_key

    @property
    def container(self):
        # type: () -> string_types
        """Gets the container of this AzureOutput.

        Name of the bucket (required)

        :return: The container of this AzureOutput.
        :rtype: string_types
        """
        return self._container

    @container.setter
    def container(self, container):
        # type: (string_types) -> None
        """Sets the container of this AzureOutput.

        Name of the bucket (required)

        :param container: The container of this AzureOutput.
        :type: string_types
        """

        if container is not None:
            if not isinstance(container, string_types):
                raise TypeError("Invalid type for `container`, type has to be `string_types`")

        self._container = container

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AzureOutput, self), "to_dict"):
            result = super(AzureOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.static_ip_status import StaticIpStatus
import pprint
import six


class StaticIp(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 ip_address=None,
                 infrastructure_id=None,
                 status=None,
                 region=None):
        # type: (string_types, string_types, string_types, StaticIpStatus, CloudRegion) -> None
        super(StaticIp, self).__init__(id_=id_)

        self._ip_address = None
        self._infrastructure_id = None
        self._status = None
        self._region = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if infrastructure_id is not None:
            self.infrastructure_id = infrastructure_id
        if status is not None:
            self.status = status
        if region is not None:
            self.region = region

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StaticIp, self), 'openapi_types'):
            types = getattr(super(StaticIp, self), 'openapi_types')

        types.update({
            'ip_address': 'string_types',
            'infrastructure_id': 'string_types',
            'status': 'StaticIpStatus',
            'region': 'CloudRegion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StaticIp, self), 'attribute_map'):
            attributes = getattr(super(StaticIp, self), 'attribute_map')

        attributes.update({
            'ip_address': 'ipAddress',
            'infrastructure_id': 'infrastructureId',
            'status': 'status',
            'region': 'region'
        })
        return attributes

    @property
    def ip_address(self):
        # type: () -> string_types
        """Gets the ip_address of this StaticIp.

        The IPv4 address of the static ip

        :return: The ip_address of this StaticIp.
        :rtype: string_types
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        # type: (string_types) -> None
        """Sets the ip_address of this StaticIp.

        The IPv4 address of the static ip

        :param ip_address: The ip_address of this StaticIp.
        :type: string_types
        """

        if ip_address is not None:
            if not isinstance(ip_address, string_types):
                raise TypeError("Invalid type for `ip_address`, type has to be `string_types`")

        self._ip_address = ip_address

    @property
    def infrastructure_id(self):
        # type: () -> string_types
        """Gets the infrastructure_id of this StaticIp.

        Required if the static IP should be created for an AWS infrastructure account.

        :return: The infrastructure_id of this StaticIp.
        :rtype: string_types
        """
        return self._infrastructure_id

    @infrastructure_id.setter
    def infrastructure_id(self, infrastructure_id):
        # type: (string_types) -> None
        """Sets the infrastructure_id of this StaticIp.

        Required if the static IP should be created for an AWS infrastructure account.

        :param infrastructure_id: The infrastructure_id of this StaticIp.
        :type: string_types
        """

        if infrastructure_id is not None:
            if not isinstance(infrastructure_id, string_types):
                raise TypeError("Invalid type for `infrastructure_id`, type has to be `string_types`")

        self._infrastructure_id = infrastructure_id

    @property
    def status(self):
        # type: () -> StaticIpStatus
        """Gets the status of this StaticIp.

        Status of the Static Ip

        :return: The status of this StaticIp.
        :rtype: StaticIpStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (StaticIpStatus) -> None
        """Sets the status of this StaticIp.

        Status of the Static Ip

        :param status: The status of this StaticIp.
        :type: StaticIpStatus
        """

        if status is not None:
            if not isinstance(status, StaticIpStatus):
                raise TypeError("Invalid type for `status`, type has to be `StaticIpStatus`")

        self._status = status

    @property
    def region(self):
        # type: () -> CloudRegion
        """Gets the region of this StaticIp.

        The region of the static Ip (required)

        :return: The region of this StaticIp.
        :rtype: CloudRegion
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (CloudRegion) -> None
        """Sets the region of this StaticIp.

        The region of the static Ip (required)

        :param region: The region of this StaticIp.
        :type: CloudRegion
        """

        if region is not None:
            if not isinstance(region, CloudRegion):
                raise TypeError("Invalid type for `region`, type has to be `CloudRegion`")

        self._region = region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StaticIp, self), "to_dict"):
            result = super(StaticIp, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StaticIp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input_stream import InputStream
import pprint
import six


class TimecodeTrackTrimmingInputStream(InputStream):
    @poscheck_model
    def __init__(self,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 id_=None,
                 input_stream_id=None,
                 start_time_code=None,
                 end_time_code=None):
        # type: (string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types, string_types) -> None
        super(TimecodeTrackTrimmingInputStream, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_)

        self._input_stream_id = None
        self._start_time_code = None
        self._end_time_code = None
        self.discriminator = None

        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if start_time_code is not None:
            self.start_time_code = start_time_code
        if end_time_code is not None:
            self.end_time_code = end_time_code

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(TimecodeTrackTrimmingInputStream, self), 'openapi_types'):
            types = getattr(super(TimecodeTrackTrimmingInputStream, self), 'openapi_types')

        types.update({
            'input_stream_id': 'string_types',
            'start_time_code': 'string_types',
            'end_time_code': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(TimecodeTrackTrimmingInputStream, self), 'attribute_map'):
            attributes = getattr(super(TimecodeTrackTrimmingInputStream, self), 'attribute_map')

        attributes.update({
            'input_stream_id': 'inputStreamId',
            'start_time_code': 'startTimeCode',
            'end_time_code': 'endTimeCode'
        })
        return attributes

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this TimecodeTrackTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :return: The input_stream_id of this TimecodeTrackTrimmingInputStream.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this TimecodeTrackTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :param input_stream_id: The input_stream_id of this TimecodeTrackTrimmingInputStream.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def start_time_code(self):
        # type: () -> string_types
        """Gets the start_time_code of this TimecodeTrackTrimmingInputStream.

        Defines the timecode, in SMPTE-12M format, of the frame from which the encoding should start. The frame indicated by this value will be included in the encoding

        :return: The start_time_code of this TimecodeTrackTrimmingInputStream.
        :rtype: string_types
        """
        return self._start_time_code

    @start_time_code.setter
    def start_time_code(self, start_time_code):
        # type: (string_types) -> None
        """Sets the start_time_code of this TimecodeTrackTrimmingInputStream.

        Defines the timecode, in SMPTE-12M format, of the frame from which the encoding should start. The frame indicated by this value will be included in the encoding

        :param start_time_code: The start_time_code of this TimecodeTrackTrimmingInputStream.
        :type: string_types
        """

        if start_time_code is not None:
            if not isinstance(start_time_code, string_types):
                raise TypeError("Invalid type for `start_time_code`, type has to be `string_types`")

        self._start_time_code = start_time_code

    @property
    def end_time_code(self):
        # type: () -> string_types
        """Gets the end_time_code of this TimecodeTrackTrimmingInputStream.

        Defines the timecode, in SMPTE-12M format, of the frame at which the encoding should stop. The frame indicated by this value will be included in the encoding

        :return: The end_time_code of this TimecodeTrackTrimmingInputStream.
        :rtype: string_types
        """
        return self._end_time_code

    @end_time_code.setter
    def end_time_code(self, end_time_code):
        # type: (string_types) -> None
        """Sets the end_time_code of this TimecodeTrackTrimmingInputStream.

        Defines the timecode, in SMPTE-12M format, of the frame at which the encoding should stop. The frame indicated by this value will be included in the encoding

        :param end_time_code: The end_time_code of this TimecodeTrackTrimmingInputStream.
        :type: string_types
        """

        if end_time_code is not None:
            if not isinstance(end_time_code, string_types):
                raise TypeError("Invalid type for `end_time_code`, type has to be `string_types`")

        self._end_time_code = end_time_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(TimecodeTrackTrimmingInputStream, self), "to_dict"):
            result = super(TimecodeTrackTrimmingInputStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimecodeTrackTrimmingInputStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class ZixiInput(Input):
    @poscheck_model
    def __init__(self,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 id_=None,
                 host=None,
                 port=None,
                 stream=None,
                 password=None,
                 latency=None,
                 min_bitrate=None,
                 decryption_type=None,
                 decryption_key=None):
        # type: (string_types, string_types, datetime, datetime, dict, string_types, string_types, int, string_types, string_types, int, int, string_types, string_types) -> None
        super(ZixiInput, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_)

        self._host = None
        self._port = None
        self._stream = None
        self._password = None
        self._latency = None
        self._min_bitrate = None
        self._decryption_type = None
        self._decryption_key = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if stream is not None:
            self.stream = stream
        if password is not None:
            self.password = password
        if latency is not None:
            self.latency = latency
        if min_bitrate is not None:
            self.min_bitrate = min_bitrate
        if decryption_type is not None:
            self.decryption_type = decryption_type
        if decryption_key is not None:
            self.decryption_key = decryption_key

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ZixiInput, self), 'openapi_types'):
            types = getattr(super(ZixiInput, self), 'openapi_types')

        types.update({
            'host': 'string_types',
            'port': 'int',
            'stream': 'string_types',
            'password': 'string_types',
            'latency': 'int',
            'min_bitrate': 'int',
            'decryption_type': 'string_types',
            'decryption_key': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ZixiInput, self), 'attribute_map'):
            attributes = getattr(super(ZixiInput, self), 'attribute_map')

        attributes.update({
            'host': 'host',
            'port': 'port',
            'stream': 'stream',
            'password': 'password',
            'latency': 'latency',
            'min_bitrate': 'minBitrate',
            'decryption_type': 'decryptionType',
            'decryption_key': 'decryptionKey'
        })
        return attributes

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this ZixiInput.


        :return: The host of this ZixiInput.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this ZixiInput.


        :param host: The host of this ZixiInput.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def port(self):
        # type: () -> int
        """Gets the port of this ZixiInput.


        :return: The port of this ZixiInput.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        # type: (int) -> None
        """Sets the port of this ZixiInput.


        :param port: The port of this ZixiInput.
        :type: int
        """

        if port is not None:
            if not isinstance(port, int):
                raise TypeError("Invalid type for `port`, type has to be `int`")

        self._port = port

    @property
    def stream(self):
        # type: () -> string_types
        """Gets the stream of this ZixiInput.


        :return: The stream of this ZixiInput.
        :rtype: string_types
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        # type: (string_types) -> None
        """Sets the stream of this ZixiInput.


        :param stream: The stream of this ZixiInput.
        :type: string_types
        """

        if stream is not None:
            if not isinstance(stream, string_types):
                raise TypeError("Invalid type for `stream`, type has to be `string_types`")

        self._stream = stream

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this ZixiInput.


        :return: The password of this ZixiInput.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this ZixiInput.


        :param password: The password of this ZixiInput.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    @property
    def latency(self):
        # type: () -> int
        """Gets the latency of this ZixiInput.


        :return: The latency of this ZixiInput.
        :rtype: int
        """
        return self._latency

    @latency.setter
    def latency(self, latency):
        # type: (int) -> None
        """Sets the latency of this ZixiInput.


        :param latency: The latency of this ZixiInput.
        :type: int
        """

        if latency is not None:
            if not isinstance(latency, int):
                raise TypeError("Invalid type for `latency`, type has to be `int`")

        self._latency = latency

    @property
    def min_bitrate(self):
        # type: () -> int
        """Gets the min_bitrate of this ZixiInput.


        :return: The min_bitrate of this ZixiInput.
        :rtype: int
        """
        return self._min_bitrate

    @min_bitrate.setter
    def min_bitrate(self, min_bitrate):
        # type: (int) -> None
        """Sets the min_bitrate of this ZixiInput.


        :param min_bitrate: The min_bitrate of this ZixiInput.
        :type: int
        """

        if min_bitrate is not None:
            if not isinstance(min_bitrate, int):
                raise TypeError("Invalid type for `min_bitrate`, type has to be `int`")

        self._min_bitrate = min_bitrate

    @property
    def decryption_type(self):
        # type: () -> string_types
        """Gets the decryption_type of this ZixiInput.


        :return: The decryption_type of this ZixiInput.
        :rtype: string_types
        """
        return self._decryption_type

    @decryption_type.setter
    def decryption_type(self, decryption_type):
        # type: (string_types) -> None
        """Sets the decryption_type of this ZixiInput.


        :param decryption_type: The decryption_type of this ZixiInput.
        :type: string_types
        """

        if decryption_type is not None:
            if not isinstance(decryption_type, string_types):
                raise TypeError("Invalid type for `decryption_type`, type has to be `string_types`")

        self._decryption_type = decryption_type

    @property
    def decryption_key(self):
        # type: () -> string_types
        """Gets the decryption_key of this ZixiInput.


        :return: The decryption_key of this ZixiInput.
        :rtype: string_types
        """
        return self._decryption_key

    @decryption_key.setter
    def decryption_key(self, decryption_key):
        # type: (string_types) -> None
        """Sets the decryption_key of this ZixiInput.


        :param decryption_key: The decryption_key of this ZixiInput.
        :type: string_types
        """

        if decryption_key is not None:
            if not isinstance(decryption_key, string_types):
                raise TypeError("Invalid type for `decryption_key`, type has to be `string_types`")

        self._decryption_key = decryption_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ZixiInput, self), "to_dict"):
            result = super(ZixiInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ZixiInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_license_custom_data_field_labels import AnalyticsLicenseCustomDataFieldLabels
import pprint
import six


class AnalyticsLicenseUpdateRequest(object):
    @poscheck_model
    def __init__(self,
                 name=None,
                 ignore_dnt=None,
                 time_zone=None,
                 custom_data_field_labels=None):
        # type: (string_types, bool, string_types, AnalyticsLicenseCustomDataFieldLabels) -> None

        self._name = None
        self._ignore_dnt = None
        self._time_zone = None
        self._custom_data_field_labels = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if ignore_dnt is not None:
            self.ignore_dnt = ignore_dnt
        if time_zone is not None:
            self.time_zone = time_zone
        if custom_data_field_labels is not None:
            self.custom_data_field_labels = custom_data_field_labels

    @property
    def openapi_types(self):
        types = {
            'name': 'string_types',
            'ignore_dnt': 'bool',
            'time_zone': 'string_types',
            'custom_data_field_labels': 'AnalyticsLicenseCustomDataFieldLabels'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'name': 'name',
            'ignore_dnt': 'ignoreDNT',
            'time_zone': 'timeZone',
            'custom_data_field_labels': 'customDataFieldLabels'
        }
        return attributes

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsLicenseUpdateRequest.


        :return: The name of this AnalyticsLicenseUpdateRequest.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsLicenseUpdateRequest.


        :param name: The name of this AnalyticsLicenseUpdateRequest.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def ignore_dnt(self):
        # type: () -> bool
        """Gets the ignore_dnt of this AnalyticsLicenseUpdateRequest.


        :return: The ignore_dnt of this AnalyticsLicenseUpdateRequest.
        :rtype: bool
        """
        return self._ignore_dnt

    @ignore_dnt.setter
    def ignore_dnt(self, ignore_dnt):
        # type: (bool) -> None
        """Sets the ignore_dnt of this AnalyticsLicenseUpdateRequest.


        :param ignore_dnt: The ignore_dnt of this AnalyticsLicenseUpdateRequest.
        :type: bool
        """

        if ignore_dnt is not None:
            if not isinstance(ignore_dnt, bool):
                raise TypeError("Invalid type for `ignore_dnt`, type has to be `bool`")

        self._ignore_dnt = ignore_dnt

    @property
    def time_zone(self):
        # type: () -> string_types
        """Gets the time_zone of this AnalyticsLicenseUpdateRequest.


        :return: The time_zone of this AnalyticsLicenseUpdateRequest.
        :rtype: string_types
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        # type: (string_types) -> None
        """Sets the time_zone of this AnalyticsLicenseUpdateRequest.


        :param time_zone: The time_zone of this AnalyticsLicenseUpdateRequest.
        :type: string_types
        """

        if time_zone is not None:
            if not isinstance(time_zone, string_types):
                raise TypeError("Invalid type for `time_zone`, type has to be `string_types`")

        self._time_zone = time_zone

    @property
    def custom_data_field_labels(self):
        # type: () -> AnalyticsLicenseCustomDataFieldLabels
        """Gets the custom_data_field_labels of this AnalyticsLicenseUpdateRequest.

        Labels for CustomData fields

        :return: The custom_data_field_labels of this AnalyticsLicenseUpdateRequest.
        :rtype: AnalyticsLicenseCustomDataFieldLabels
        """
        return self._custom_data_field_labels

    @custom_data_field_labels.setter
    def custom_data_field_labels(self, custom_data_field_labels):
        # type: (AnalyticsLicenseCustomDataFieldLabels) -> None
        """Sets the custom_data_field_labels of this AnalyticsLicenseUpdateRequest.

        Labels for CustomData fields

        :param custom_data_field_labels: The custom_data_field_labels of this AnalyticsLicenseUpdateRequest.
        :type: AnalyticsLicenseCustomDataFieldLabels
        """

        if custom_data_field_labels is not None:
            if not isinstance(custom_data_field_labels, AnalyticsLicenseCustomDataFieldLabels):
                raise TypeError("Invalid type for `custom_data_field_labels`, type has to be `AnalyticsLicenseCustomDataFieldLabels`")

        self._custom_data_field_labels = custom_data_field_labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicenseUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.object_detection_api import ObjectDetectionApi
from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.results.results_api import ResultsApi
from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.object_detection_configuration_list_query_params import ObjectDetectionConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AzureCloudRegion(Enum):
    US_WEST = "US_WEST"
    US_WEST2 = "US_WEST2"
    US_CENTRAL = "US_CENTRAL"
    US_EAST = "US_EAST"
    US_EAST2 = "US_EAST2"
    US_NORTH_CENTRAL = "US_NORTH_CENTRAL"
    US_SOUTH_CENTRAL = "US_SOUTH_CENTRAL"
    US_WEST_CENTRAL = "US_WEST_CENTRAL"
    CANADA_CENTRAL = "CANADA_CENTRAL"
    CANADA_EAST = "CANADA_EAST"
    BRAZIL_SOUTH = "BRAZIL_SOUTH"
    EUROPE_NORTH = "EUROPE_NORTH"
    EUROPE_WEST = "EUROPE_WEST"
    UK_SOUTH = "UK_SOUTH"
    UK_WEST = "UK_WEST"
    ASIA_EAST = "ASIA_EAST"
    ASIA_SOUTHEAST = "ASIA_SOUTHEAST"
    JAPAN_EAST = "JAPAN_EAST"
    JAPAN_WEST = "JAPAN_WEST"
    AUSTRALIA_EAST = "AUSTRALIA_EAST"
    AUSTRALIA_SOUTHEAST = "AUSTRALIA_SOUTHEAST"
    INDIA_CENTRAL = "INDIA_CENTRAL"
    INDIA_SOUTH = "INDIA_SOUTH"
    INDIA_WEST = "INDIA_WEST"
    KOREA_CENTRAL = "KOREA_CENTRAL"
    KOREA_SOUTH = "KOREA_SOUTH"
    CHINA_NORTH = "CHINA_NORTH"
    CHINA_EAST = "CHINA_EAST"
    GERMANY_CENTRAL = "GERMANY_CENTRAL"
    GERMANY_NORTHEAST = "GERMANY_NORTHEAST"
    GOV_US_VIRGINIA = "GOV_US_VIRGINIA"
    GOV_US_IOWA = "GOV_US_IOWA"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class GceAccount(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 service_account_email=None,
                 private_key=None,
                 project_id=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types) -> None
        super(GceAccount, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._service_account_email = None
        self._private_key = None
        self._project_id = None
        self.discriminator = None

        if service_account_email is not None:
            self.service_account_email = service_account_email
        if private_key is not None:
            self.private_key = private_key
        if project_id is not None:
            self.project_id = project_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(GceAccount, self), 'openapi_types'):
            types = getattr(super(GceAccount, self), 'openapi_types')

        types.update({
            'service_account_email': 'string_types',
            'private_key': 'string_types',
            'project_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(GceAccount, self), 'attribute_map'):
            attributes = getattr(super(GceAccount, self), 'attribute_map')

        attributes.update({
            'service_account_email': 'serviceAccountEmail',
            'private_key': 'privateKey',
            'project_id': 'projectId'
        })
        return attributes

    @property
    def service_account_email(self):
        # type: () -> string_types
        """Gets the service_account_email of this GceAccount.

        Email address of the Google service account that will be used to spin up VMs (required)

        :return: The service_account_email of this GceAccount.
        :rtype: string_types
        """
        return self._service_account_email

    @service_account_email.setter
    def service_account_email(self, service_account_email):
        # type: (string_types) -> None
        """Sets the service_account_email of this GceAccount.

        Email address of the Google service account that will be used to spin up VMs (required)

        :param service_account_email: The service_account_email of this GceAccount.
        :type: string_types
        """

        if service_account_email is not None:
            if not isinstance(service_account_email, string_types):
                raise TypeError("Invalid type for `service_account_email`, type has to be `string_types`")

        self._service_account_email = service_account_email

    @property
    def private_key(self):
        # type: () -> string_types
        """Gets the private_key of this GceAccount.

        Google private key of the Google service account that will be used to spin up VMs (required)

        :return: The private_key of this GceAccount.
        :rtype: string_types
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        # type: (string_types) -> None
        """Sets the private_key of this GceAccount.

        Google private key of the Google service account that will be used to spin up VMs (required)

        :param private_key: The private_key of this GceAccount.
        :type: string_types
        """

        if private_key is not None:
            if not isinstance(private_key, string_types):
                raise TypeError("Invalid type for `private_key`, type has to be `string_types`")

        self._private_key = private_key

    @property
    def project_id(self):
        # type: () -> string_types
        """Gets the project_id of this GceAccount.

        ID of the GCP project in which the VMs are supposed to run. (required)

        :return: The project_id of this GceAccount.
        :rtype: string_types
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        # type: (string_types) -> None
        """Sets the project_id of this GceAccount.

        ID of the GCP project in which the VMs are supposed to run. (required)

        :param project_id: The project_id of this GceAccount.
        :type: string_types
        """

        if project_id is not None:
            if not isinstance(project_id, string_types):
                raise TypeError("Invalid type for `project_id`, type has to be `string_types`")

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(GceAccount, self), "to_dict"):
            result = super(GceAccount, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GceAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dash_mp4_representation import DashMp4Representation
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.dash_mp4_representation_list_query_params import DashMp4RepresentationListQueryParams


class Mp4Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Mp4Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.drm = DrmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, period_id, adaptationset_id, dash_mp4_representation, **kwargs):
        # type: (string_types, string_types, string_types, DashMp4Representation, dict) -> DashMp4Representation
        """Add MP4 Representation

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param dash_mp4_representation: The MP4 representation to be added to the adaptation set
        :type dash_mp4_representation: DashMp4Representation, required
        :return: Id of the MP4 representation
        :rtype: DashMp4Representation
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/mp4',
            dash_mp4_representation,
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id},
            type=DashMp4Representation,
            **kwargs
        )

    def delete(self, manifest_id, period_id, adaptationset_id, representation_id, **kwargs):
        # type: (string_types, string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete MP4 Representation

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the MP4 representation to be deleted
        :type representation_id: string_types, required
        :return: Id of the MP4 Representation
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/mp4/{representation_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, period_id, adaptationset_id, representation_id, **kwargs):
        # type: (string_types, string_types, string_types, string_types, dict) -> DashMp4Representation
        """MP4 Representation Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the representation
        :type representation_id: string_types, required
        :return: MP4 Representation details
        :rtype: DashMp4Representation
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/mp4/{representation_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id},
            type=DashMp4Representation,
            **kwargs
        )

    def list(self, manifest_id, period_id, adaptationset_id, query_params=None, **kwargs):
        # type: (string_types, string_types, string_types, DashMp4RepresentationListQueryParams, dict) -> DashMp4Representation
        """List all MP4 Representations

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DashMp4RepresentationListQueryParams
        :return: List of MP4 Representations
        :rtype: DashMp4Representation
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/mp4',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id},
            query_params=query_params,
            pagination_response=True,
            type=DashMp4Representation,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.av1_adaptive_quant_mode import Av1AdaptiveQuantMode
from bitmovin_api_sdk.models.av1_key_placement_mode import Av1KeyPlacementMode
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
import pprint
import six


class Av1VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 id_=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 key_placement_mode=None,
                 adaptive_quant_mode=None,
                 lag_in_frames=None,
                 min_q=None,
                 max_q=None,
                 undershoot_pct=None,
                 overshoot_pct=None,
                 client_buffer_size=None,
                 client_initial_buffer_size=None,
                 client_optimal_buffer_size=None,
                 tile_columns=None,
                 tile_rows=None,
                 is_automatic_alt_ref_frames_enabled=None,
                 arnr_max_frames=None,
                 arnr_strength=None,
                 max_intra_rate=None,
                 is_lossless=None,
                 is_frame_parallel=None,
                 sharpness=None,
                 is_frame_boost_enabled=None,
                 noise_sensitivity=None,
                 min_gf_interval=None,
                 max_gf_interval=None,
                 num_tile_groups=None,
                 mtu_size=None):
        # type: (string_types, string_types, datetime, datetime, dict, string_types, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, Av1KeyPlacementMode, Av1AdaptiveQuantMode, int, int, int, int, int, int, int, int, int, int, bool, int, int, int, bool, bool, int, bool, bool, int, int, int, int) -> None
        super(Av1VideoConfiguration, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._key_placement_mode = None
        self._adaptive_quant_mode = None
        self._lag_in_frames = None
        self._min_q = None
        self._max_q = None
        self._undershoot_pct = None
        self._overshoot_pct = None
        self._client_buffer_size = None
        self._client_initial_buffer_size = None
        self._client_optimal_buffer_size = None
        self._tile_columns = None
        self._tile_rows = None
        self._is_automatic_alt_ref_frames_enabled = None
        self._arnr_max_frames = None
        self._arnr_strength = None
        self._max_intra_rate = None
        self._is_lossless = None
        self._is_frame_parallel = None
        self._sharpness = None
        self._is_frame_boost_enabled = None
        self._noise_sensitivity = None
        self._min_gf_interval = None
        self._max_gf_interval = None
        self._num_tile_groups = None
        self._mtu_size = None
        self.discriminator = None

        if key_placement_mode is not None:
            self.key_placement_mode = key_placement_mode
        if adaptive_quant_mode is not None:
            self.adaptive_quant_mode = adaptive_quant_mode
        if lag_in_frames is not None:
            self.lag_in_frames = lag_in_frames
        if min_q is not None:
            self.min_q = min_q
        if max_q is not None:
            self.max_q = max_q
        if undershoot_pct is not None:
            self.undershoot_pct = undershoot_pct
        if overshoot_pct is not None:
            self.overshoot_pct = overshoot_pct
        if client_buffer_size is not None:
            self.client_buffer_size = client_buffer_size
        if client_initial_buffer_size is not None:
            self.client_initial_buffer_size = client_initial_buffer_size
        if client_optimal_buffer_size is not None:
            self.client_optimal_buffer_size = client_optimal_buffer_size
        if tile_columns is not None:
            self.tile_columns = tile_columns
        if tile_rows is not None:
            self.tile_rows = tile_rows
        if is_automatic_alt_ref_frames_enabled is not None:
            self.is_automatic_alt_ref_frames_enabled = is_automatic_alt_ref_frames_enabled
        if arnr_max_frames is not None:
            self.arnr_max_frames = arnr_max_frames
        if arnr_strength is not None:
            self.arnr_strength = arnr_strength
        if max_intra_rate is not None:
            self.max_intra_rate = max_intra_rate
        if is_lossless is not None:
            self.is_lossless = is_lossless
        if is_frame_parallel is not None:
            self.is_frame_parallel = is_frame_parallel
        if sharpness is not None:
            self.sharpness = sharpness
        if is_frame_boost_enabled is not None:
            self.is_frame_boost_enabled = is_frame_boost_enabled
        if noise_sensitivity is not None:
            self.noise_sensitivity = noise_sensitivity
        if min_gf_interval is not None:
            self.min_gf_interval = min_gf_interval
        if max_gf_interval is not None:
            self.max_gf_interval = max_gf_interval
        if num_tile_groups is not None:
            self.num_tile_groups = num_tile_groups
        if mtu_size is not None:
            self.mtu_size = mtu_size

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Av1VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Av1VideoConfiguration, self), 'openapi_types')

        types.update({
            'key_placement_mode': 'Av1KeyPlacementMode',
            'adaptive_quant_mode': 'Av1AdaptiveQuantMode',
            'lag_in_frames': 'int',
            'min_q': 'int',
            'max_q': 'int',
            'undershoot_pct': 'int',
            'overshoot_pct': 'int',
            'client_buffer_size': 'int',
            'client_initial_buffer_size': 'int',
            'client_optimal_buffer_size': 'int',
            'tile_columns': 'int',
            'tile_rows': 'int',
            'is_automatic_alt_ref_frames_enabled': 'bool',
            'arnr_max_frames': 'int',
            'arnr_strength': 'int',
            'max_intra_rate': 'int',
            'is_lossless': 'bool',
            'is_frame_parallel': 'bool',
            'sharpness': 'int',
            'is_frame_boost_enabled': 'bool',
            'noise_sensitivity': 'bool',
            'min_gf_interval': 'int',
            'max_gf_interval': 'int',
            'num_tile_groups': 'int',
            'mtu_size': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Av1VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Av1VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'key_placement_mode': 'keyPlacementMode',
            'adaptive_quant_mode': 'adaptiveQuantMode',
            'lag_in_frames': 'lagInFrames',
            'min_q': 'minQ',
            'max_q': 'maxQ',
            'undershoot_pct': 'undershootPct',
            'overshoot_pct': 'overshootPct',
            'client_buffer_size': 'clientBufferSize',
            'client_initial_buffer_size': 'clientInitialBufferSize',
            'client_optimal_buffer_size': 'clientOptimalBufferSize',
            'tile_columns': 'tileColumns',
            'tile_rows': 'tileRows',
            'is_automatic_alt_ref_frames_enabled': 'isAutomaticAltRefFramesEnabled',
            'arnr_max_frames': 'arnrMaxFrames',
            'arnr_strength': 'arnrStrength',
            'max_intra_rate': 'maxIntraRate',
            'is_lossless': 'isLossless',
            'is_frame_parallel': 'isFrameParallel',
            'sharpness': 'sharpness',
            'is_frame_boost_enabled': 'isFrameBoostEnabled',
            'noise_sensitivity': 'noiseSensitivity',
            'min_gf_interval': 'minGfInterval',
            'max_gf_interval': 'maxGfInterval',
            'num_tile_groups': 'numTileGroups',
            'mtu_size': 'mtuSize'
        })
        return attributes

    @property
    def key_placement_mode(self):
        # type: () -> Av1KeyPlacementMode
        """Gets the key_placement_mode of this Av1VideoConfiguration.


        :return: The key_placement_mode of this Av1VideoConfiguration.
        :rtype: Av1KeyPlacementMode
        """
        return self._key_placement_mode

    @key_placement_mode.setter
    def key_placement_mode(self, key_placement_mode):
        # type: (Av1KeyPlacementMode) -> None
        """Sets the key_placement_mode of this Av1VideoConfiguration.


        :param key_placement_mode: The key_placement_mode of this Av1VideoConfiguration.
        :type: Av1KeyPlacementMode
        """

        if key_placement_mode is not None:
            if not isinstance(key_placement_mode, Av1KeyPlacementMode):
                raise TypeError("Invalid type for `key_placement_mode`, type has to be `Av1KeyPlacementMode`")

        self._key_placement_mode = key_placement_mode

    @property
    def adaptive_quant_mode(self):
        # type: () -> Av1AdaptiveQuantMode
        """Gets the adaptive_quant_mode of this Av1VideoConfiguration.


        :return: The adaptive_quant_mode of this Av1VideoConfiguration.
        :rtype: Av1AdaptiveQuantMode
        """
        return self._adaptive_quant_mode

    @adaptive_quant_mode.setter
    def adaptive_quant_mode(self, adaptive_quant_mode):
        # type: (Av1AdaptiveQuantMode) -> None
        """Sets the adaptive_quant_mode of this Av1VideoConfiguration.


        :param adaptive_quant_mode: The adaptive_quant_mode of this Av1VideoConfiguration.
        :type: Av1AdaptiveQuantMode
        """

        if adaptive_quant_mode is not None:
            if not isinstance(adaptive_quant_mode, Av1AdaptiveQuantMode):
                raise TypeError("Invalid type for `adaptive_quant_mode`, type has to be `Av1AdaptiveQuantMode`")

        self._adaptive_quant_mode = adaptive_quant_mode

    @property
    def lag_in_frames(self):
        # type: () -> int
        """Gets the lag_in_frames of this Av1VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection

        :return: The lag_in_frames of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._lag_in_frames

    @lag_in_frames.setter
    def lag_in_frames(self, lag_in_frames):
        # type: (int) -> None
        """Sets the lag_in_frames of this Av1VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection

        :param lag_in_frames: The lag_in_frames of this Av1VideoConfiguration.
        :type: int
        """

        if lag_in_frames is not None:
            if lag_in_frames is not None and lag_in_frames > 25:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value less than or equal to `25`")
            if lag_in_frames is not None and lag_in_frames < 0:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value greater than or equal to `0`")
            if not isinstance(lag_in_frames, int):
                raise TypeError("Invalid type for `lag_in_frames`, type has to be `int`")

        self._lag_in_frames = lag_in_frames

    @property
    def min_q(self):
        # type: () -> int
        """Gets the min_q of this Av1VideoConfiguration.

        Minimum (best quality) quantizer

        :return: The min_q of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._min_q

    @min_q.setter
    def min_q(self, min_q):
        # type: (int) -> None
        """Sets the min_q of this Av1VideoConfiguration.

        Minimum (best quality) quantizer

        :param min_q: The min_q of this Av1VideoConfiguration.
        :type: int
        """

        if min_q is not None:
            if not isinstance(min_q, int):
                raise TypeError("Invalid type for `min_q`, type has to be `int`")

        self._min_q = min_q

    @property
    def max_q(self):
        # type: () -> int
        """Gets the max_q of this Av1VideoConfiguration.

        Maximum (worst quality) quantizer

        :return: The max_q of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._max_q

    @max_q.setter
    def max_q(self, max_q):
        # type: (int) -> None
        """Sets the max_q of this Av1VideoConfiguration.

        Maximum (worst quality) quantizer

        :param max_q: The max_q of this Av1VideoConfiguration.
        :type: int
        """

        if max_q is not None:
            if not isinstance(max_q, int):
                raise TypeError("Invalid type for `max_q`, type has to be `int`")

        self._max_q = max_q

    @property
    def undershoot_pct(self):
        # type: () -> int
        """Gets the undershoot_pct of this Av1VideoConfiguration.

        Rate control adaptation undershoot control

        :return: The undershoot_pct of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._undershoot_pct

    @undershoot_pct.setter
    def undershoot_pct(self, undershoot_pct):
        # type: (int) -> None
        """Sets the undershoot_pct of this Av1VideoConfiguration.

        Rate control adaptation undershoot control

        :param undershoot_pct: The undershoot_pct of this Av1VideoConfiguration.
        :type: int
        """

        if undershoot_pct is not None:
            if undershoot_pct is not None and undershoot_pct > 1000:
                raise ValueError("Invalid value for `undershoot_pct`, must be a value less than or equal to `1000`")
            if undershoot_pct is not None and undershoot_pct < 0:
                raise ValueError("Invalid value for `undershoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(undershoot_pct, int):
                raise TypeError("Invalid type for `undershoot_pct`, type has to be `int`")

        self._undershoot_pct = undershoot_pct

    @property
    def overshoot_pct(self):
        # type: () -> int
        """Gets the overshoot_pct of this Av1VideoConfiguration.

        Rate control adaptation overshoot control

        :return: The overshoot_pct of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._overshoot_pct

    @overshoot_pct.setter
    def overshoot_pct(self, overshoot_pct):
        # type: (int) -> None
        """Sets the overshoot_pct of this Av1VideoConfiguration.

        Rate control adaptation overshoot control

        :param overshoot_pct: The overshoot_pct of this Av1VideoConfiguration.
        :type: int
        """

        if overshoot_pct is not None:
            if overshoot_pct is not None and overshoot_pct > 1000:
                raise ValueError("Invalid value for `overshoot_pct`, must be a value less than or equal to `1000`")
            if overshoot_pct is not None and overshoot_pct < 0:
                raise ValueError("Invalid value for `overshoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(overshoot_pct, int):
                raise TypeError("Invalid type for `overshoot_pct`, type has to be `int`")

        self._overshoot_pct = overshoot_pct

    @property
    def client_buffer_size(self):
        # type: () -> int
        """Gets the client_buffer_size of this Av1VideoConfiguration.

        Decoder buffer size in milliseconds

        :return: The client_buffer_size of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._client_buffer_size

    @client_buffer_size.setter
    def client_buffer_size(self, client_buffer_size):
        # type: (int) -> None
        """Sets the client_buffer_size of this Av1VideoConfiguration.

        Decoder buffer size in milliseconds

        :param client_buffer_size: The client_buffer_size of this Av1VideoConfiguration.
        :type: int
        """

        if client_buffer_size is not None:
            if not isinstance(client_buffer_size, int):
                raise TypeError("Invalid type for `client_buffer_size`, type has to be `int`")

        self._client_buffer_size = client_buffer_size

    @property
    def client_initial_buffer_size(self):
        # type: () -> int
        """Gets the client_initial_buffer_size of this Av1VideoConfiguration.

        Decoder buffer initial size in milliseconds

        :return: The client_initial_buffer_size of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._client_initial_buffer_size

    @client_initial_buffer_size.setter
    def client_initial_buffer_size(self, client_initial_buffer_size):
        # type: (int) -> None
        """Sets the client_initial_buffer_size of this Av1VideoConfiguration.

        Decoder buffer initial size in milliseconds

        :param client_initial_buffer_size: The client_initial_buffer_size of this Av1VideoConfiguration.
        :type: int
        """

        if client_initial_buffer_size is not None:
            if not isinstance(client_initial_buffer_size, int):
                raise TypeError("Invalid type for `client_initial_buffer_size`, type has to be `int`")

        self._client_initial_buffer_size = client_initial_buffer_size

    @property
    def client_optimal_buffer_size(self):
        # type: () -> int
        """Gets the client_optimal_buffer_size of this Av1VideoConfiguration.

        Decoder buffer optimal size in milliseconds

        :return: The client_optimal_buffer_size of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._client_optimal_buffer_size

    @client_optimal_buffer_size.setter
    def client_optimal_buffer_size(self, client_optimal_buffer_size):
        # type: (int) -> None
        """Sets the client_optimal_buffer_size of this Av1VideoConfiguration.

        Decoder buffer optimal size in milliseconds

        :param client_optimal_buffer_size: The client_optimal_buffer_size of this Av1VideoConfiguration.
        :type: int
        """

        if client_optimal_buffer_size is not None:
            if not isinstance(client_optimal_buffer_size, int):
                raise TypeError("Invalid type for `client_optimal_buffer_size`, type has to be `int`")

        self._client_optimal_buffer_size = client_optimal_buffer_size

    @property
    def tile_columns(self):
        # type: () -> int
        """Gets the tile_columns of this Av1VideoConfiguration.

        Number of tile columns to use, log2

        :return: The tile_columns of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._tile_columns

    @tile_columns.setter
    def tile_columns(self, tile_columns):
        # type: (int) -> None
        """Sets the tile_columns of this Av1VideoConfiguration.

        Number of tile columns to use, log2

        :param tile_columns: The tile_columns of this Av1VideoConfiguration.
        :type: int
        """

        if tile_columns is not None:
            if tile_columns is not None and tile_columns > 6:
                raise ValueError("Invalid value for `tile_columns`, must be a value less than or equal to `6`")
            if tile_columns is not None and tile_columns < 0:
                raise ValueError("Invalid value for `tile_columns`, must be a value greater than or equal to `0`")
            if not isinstance(tile_columns, int):
                raise TypeError("Invalid type for `tile_columns`, type has to be `int`")

        self._tile_columns = tile_columns

    @property
    def tile_rows(self):
        # type: () -> int
        """Gets the tile_rows of this Av1VideoConfiguration.

        Number of tile rows to use, log2

        :return: The tile_rows of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._tile_rows

    @tile_rows.setter
    def tile_rows(self, tile_rows):
        # type: (int) -> None
        """Sets the tile_rows of this Av1VideoConfiguration.

        Number of tile rows to use, log2

        :param tile_rows: The tile_rows of this Av1VideoConfiguration.
        :type: int
        """

        if tile_rows is not None:
            if tile_rows is not None and tile_rows > 2:
                raise ValueError("Invalid value for `tile_rows`, must be a value less than or equal to `2`")
            if tile_rows is not None and tile_rows < 0:
                raise ValueError("Invalid value for `tile_rows`, must be a value greater than or equal to `0`")
            if not isinstance(tile_rows, int):
                raise TypeError("Invalid type for `tile_rows`, type has to be `int`")

        self._tile_rows = tile_rows

    @property
    def is_automatic_alt_ref_frames_enabled(self):
        # type: () -> bool
        """Gets the is_automatic_alt_ref_frames_enabled of this Av1VideoConfiguration.

        Enable automatic set and use alf frames

        :return: The is_automatic_alt_ref_frames_enabled of this Av1VideoConfiguration.
        :rtype: bool
        """
        return self._is_automatic_alt_ref_frames_enabled

    @is_automatic_alt_ref_frames_enabled.setter
    def is_automatic_alt_ref_frames_enabled(self, is_automatic_alt_ref_frames_enabled):
        # type: (bool) -> None
        """Sets the is_automatic_alt_ref_frames_enabled of this Av1VideoConfiguration.

        Enable automatic set and use alf frames

        :param is_automatic_alt_ref_frames_enabled: The is_automatic_alt_ref_frames_enabled of this Av1VideoConfiguration.
        :type: bool
        """

        if is_automatic_alt_ref_frames_enabled is not None:
            if not isinstance(is_automatic_alt_ref_frames_enabled, bool):
                raise TypeError("Invalid type for `is_automatic_alt_ref_frames_enabled`, type has to be `bool`")

        self._is_automatic_alt_ref_frames_enabled = is_automatic_alt_ref_frames_enabled

    @property
    def arnr_max_frames(self):
        # type: () -> int
        """Gets the arnr_max_frames of this Av1VideoConfiguration.

        The max number of frames to create arf

        :return: The arnr_max_frames of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._arnr_max_frames

    @arnr_max_frames.setter
    def arnr_max_frames(self, arnr_max_frames):
        # type: (int) -> None
        """Sets the arnr_max_frames of this Av1VideoConfiguration.

        The max number of frames to create arf

        :param arnr_max_frames: The arnr_max_frames of this Av1VideoConfiguration.
        :type: int
        """

        if arnr_max_frames is not None:
            if not isinstance(arnr_max_frames, int):
                raise TypeError("Invalid type for `arnr_max_frames`, type has to be `int`")

        self._arnr_max_frames = arnr_max_frames

    @property
    def arnr_strength(self):
        # type: () -> int
        """Gets the arnr_strength of this Av1VideoConfiguration.

        The filter strength for the arf

        :return: The arnr_strength of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._arnr_strength

    @arnr_strength.setter
    def arnr_strength(self, arnr_strength):
        # type: (int) -> None
        """Sets the arnr_strength of this Av1VideoConfiguration.

        The filter strength for the arf

        :param arnr_strength: The arnr_strength of this Av1VideoConfiguration.
        :type: int
        """

        if arnr_strength is not None:
            if not isinstance(arnr_strength, int):
                raise TypeError("Invalid type for `arnr_strength`, type has to be `int`")

        self._arnr_strength = arnr_strength

    @property
    def max_intra_rate(self):
        # type: () -> int
        """Gets the max_intra_rate of this Av1VideoConfiguration.

        Maximum data rate for intra frames, expressed as a percentage of the average per-frame bitrate. Default value 0 meaning unlimited

        :return: The max_intra_rate of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._max_intra_rate

    @max_intra_rate.setter
    def max_intra_rate(self, max_intra_rate):
        # type: (int) -> None
        """Sets the max_intra_rate of this Av1VideoConfiguration.

        Maximum data rate for intra frames, expressed as a percentage of the average per-frame bitrate. Default value 0 meaning unlimited

        :param max_intra_rate: The max_intra_rate of this Av1VideoConfiguration.
        :type: int
        """

        if max_intra_rate is not None:
            if not isinstance(max_intra_rate, int):
                raise TypeError("Invalid type for `max_intra_rate`, type has to be `int`")

        self._max_intra_rate = max_intra_rate

    @property
    def is_lossless(self):
        # type: () -> bool
        """Gets the is_lossless of this Av1VideoConfiguration.

        Lossless encoding mode

        :return: The is_lossless of this Av1VideoConfiguration.
        :rtype: bool
        """
        return self._is_lossless

    @is_lossless.setter
    def is_lossless(self, is_lossless):
        # type: (bool) -> None
        """Sets the is_lossless of this Av1VideoConfiguration.

        Lossless encoding mode

        :param is_lossless: The is_lossless of this Av1VideoConfiguration.
        :type: bool
        """

        if is_lossless is not None:
            if not isinstance(is_lossless, bool):
                raise TypeError("Invalid type for `is_lossless`, type has to be `bool`")

        self._is_lossless = is_lossless

    @property
    def is_frame_parallel(self):
        # type: () -> bool
        """Gets the is_frame_parallel of this Av1VideoConfiguration.

        Enable frame parallel decoding feature

        :return: The is_frame_parallel of this Av1VideoConfiguration.
        :rtype: bool
        """
        return self._is_frame_parallel

    @is_frame_parallel.setter
    def is_frame_parallel(self, is_frame_parallel):
        # type: (bool) -> None
        """Sets the is_frame_parallel of this Av1VideoConfiguration.

        Enable frame parallel decoding feature

        :param is_frame_parallel: The is_frame_parallel of this Av1VideoConfiguration.
        :type: bool
        """

        if is_frame_parallel is not None:
            if not isinstance(is_frame_parallel, bool):
                raise TypeError("Invalid type for `is_frame_parallel`, type has to be `bool`")

        self._is_frame_parallel = is_frame_parallel

    @property
    def sharpness(self):
        # type: () -> int
        """Gets the sharpness of this Av1VideoConfiguration.

        Sets the sharpness

        :return: The sharpness of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._sharpness

    @sharpness.setter
    def sharpness(self, sharpness):
        # type: (int) -> None
        """Sets the sharpness of this Av1VideoConfiguration.

        Sets the sharpness

        :param sharpness: The sharpness of this Av1VideoConfiguration.
        :type: int
        """

        if sharpness is not None:
            if not isinstance(sharpness, int):
                raise TypeError("Invalid type for `sharpness`, type has to be `int`")

        self._sharpness = sharpness

    @property
    def is_frame_boost_enabled(self):
        # type: () -> bool
        """Gets the is_frame_boost_enabled of this Av1VideoConfiguration.

        Enable quality boost by lowering frame level Q periodically

        :return: The is_frame_boost_enabled of this Av1VideoConfiguration.
        :rtype: bool
        """
        return self._is_frame_boost_enabled

    @is_frame_boost_enabled.setter
    def is_frame_boost_enabled(self, is_frame_boost_enabled):
        # type: (bool) -> None
        """Sets the is_frame_boost_enabled of this Av1VideoConfiguration.

        Enable quality boost by lowering frame level Q periodically

        :param is_frame_boost_enabled: The is_frame_boost_enabled of this Av1VideoConfiguration.
        :type: bool
        """

        if is_frame_boost_enabled is not None:
            if not isinstance(is_frame_boost_enabled, bool):
                raise TypeError("Invalid type for `is_frame_boost_enabled`, type has to be `bool`")

        self._is_frame_boost_enabled = is_frame_boost_enabled

    @property
    def noise_sensitivity(self):
        # type: () -> bool
        """Gets the noise_sensitivity of this Av1VideoConfiguration.

        Enable noise sensitivity on Y channel

        :return: The noise_sensitivity of this Av1VideoConfiguration.
        :rtype: bool
        """
        return self._noise_sensitivity

    @noise_sensitivity.setter
    def noise_sensitivity(self, noise_sensitivity):
        # type: (bool) -> None
        """Sets the noise_sensitivity of this Av1VideoConfiguration.

        Enable noise sensitivity on Y channel

        :param noise_sensitivity: The noise_sensitivity of this Av1VideoConfiguration.
        :type: bool
        """

        if noise_sensitivity is not None:
            if not isinstance(noise_sensitivity, bool):
                raise TypeError("Invalid type for `noise_sensitivity`, type has to be `bool`")

        self._noise_sensitivity = noise_sensitivity

    @property
    def min_gf_interval(self):
        # type: () -> int
        """Gets the min_gf_interval of this Av1VideoConfiguration.

        Minimum interval between GF/ARF frames

        :return: The min_gf_interval of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._min_gf_interval

    @min_gf_interval.setter
    def min_gf_interval(self, min_gf_interval):
        # type: (int) -> None
        """Sets the min_gf_interval of this Av1VideoConfiguration.

        Minimum interval between GF/ARF frames

        :param min_gf_interval: The min_gf_interval of this Av1VideoConfiguration.
        :type: int
        """

        if min_gf_interval is not None:
            if not isinstance(min_gf_interval, int):
                raise TypeError("Invalid type for `min_gf_interval`, type has to be `int`")

        self._min_gf_interval = min_gf_interval

    @property
    def max_gf_interval(self):
        # type: () -> int
        """Gets the max_gf_interval of this Av1VideoConfiguration.

        Maximum interval between GF/ARF frames

        :return: The max_gf_interval of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._max_gf_interval

    @max_gf_interval.setter
    def max_gf_interval(self, max_gf_interval):
        # type: (int) -> None
        """Sets the max_gf_interval of this Av1VideoConfiguration.

        Maximum interval between GF/ARF frames

        :param max_gf_interval: The max_gf_interval of this Av1VideoConfiguration.
        :type: int
        """

        if max_gf_interval is not None:
            if not isinstance(max_gf_interval, int):
                raise TypeError("Invalid type for `max_gf_interval`, type has to be `int`")

        self._max_gf_interval = max_gf_interval

    @property
    def num_tile_groups(self):
        # type: () -> int
        """Gets the num_tile_groups of this Av1VideoConfiguration.

        Maximum number of tile groups

        :return: The num_tile_groups of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._num_tile_groups

    @num_tile_groups.setter
    def num_tile_groups(self, num_tile_groups):
        # type: (int) -> None
        """Sets the num_tile_groups of this Av1VideoConfiguration.

        Maximum number of tile groups

        :param num_tile_groups: The num_tile_groups of this Av1VideoConfiguration.
        :type: int
        """

        if num_tile_groups is not None:
            if not isinstance(num_tile_groups, int):
                raise TypeError("Invalid type for `num_tile_groups`, type has to be `int`")

        self._num_tile_groups = num_tile_groups

    @property
    def mtu_size(self):
        # type: () -> int
        """Gets the mtu_size of this Av1VideoConfiguration.

        Maximum number of bytes in a tile group

        :return: The mtu_size of this Av1VideoConfiguration.
        :rtype: int
        """
        return self._mtu_size

    @mtu_size.setter
    def mtu_size(self, mtu_size):
        # type: (int) -> None
        """Sets the mtu_size of this Av1VideoConfiguration.

        Maximum number of bytes in a tile group

        :param mtu_size: The mtu_size of this Av1VideoConfiguration.
        :type: int
        """

        if mtu_size is not None:
            if not isinstance(mtu_size, int):
                raise TypeError("Invalid type for `mtu_size`, type has to be `int`")

        self._mtu_size = mtu_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Av1VideoConfiguration, self), "to_dict"):
            result = super(Av1VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Av1VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsLicenseCustomDataFieldLabels(object):
    @poscheck_model
    def __init__(self,
                 custom_data1=None,
                 custom_data2=None,
                 custom_data3=None,
                 custom_data4=None,
                 custom_data5=None):
        # type: (string_types, string_types, string_types, string_types, string_types) -> None

        self._custom_data1 = None
        self._custom_data2 = None
        self._custom_data3 = None
        self._custom_data4 = None
        self._custom_data5 = None
        self.discriminator = None

        if custom_data1 is not None:
            self.custom_data1 = custom_data1
        if custom_data2 is not None:
            self.custom_data2 = custom_data2
        if custom_data3 is not None:
            self.custom_data3 = custom_data3
        if custom_data4 is not None:
            self.custom_data4 = custom_data4
        if custom_data5 is not None:
            self.custom_data5 = custom_data5

    @property
    def openapi_types(self):
        types = {
            'custom_data1': 'string_types',
            'custom_data2': 'string_types',
            'custom_data3': 'string_types',
            'custom_data4': 'string_types',
            'custom_data5': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'custom_data1': 'customData1',
            'custom_data2': 'customData2',
            'custom_data3': 'customData3',
            'custom_data4': 'customData4',
            'custom_data5': 'customData5'
        }
        return attributes

    @property
    def custom_data1(self):
        # type: () -> string_types
        """Gets the custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 1

        :return: The custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data1

    @custom_data1.setter
    def custom_data1(self, custom_data1):
        # type: (string_types) -> None
        """Sets the custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 1

        :param custom_data1: The custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data1 is not None:
            if not isinstance(custom_data1, string_types):
                raise TypeError("Invalid type for `custom_data1`, type has to be `string_types`")

        self._custom_data1 = custom_data1

    @property
    def custom_data2(self):
        # type: () -> string_types
        """Gets the custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 2

        :return: The custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data2

    @custom_data2.setter
    def custom_data2(self, custom_data2):
        # type: (string_types) -> None
        """Sets the custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 2

        :param custom_data2: The custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data2 is not None:
            if not isinstance(custom_data2, string_types):
                raise TypeError("Invalid type for `custom_data2`, type has to be `string_types`")

        self._custom_data2 = custom_data2

    @property
    def custom_data3(self):
        # type: () -> string_types
        """Gets the custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 3

        :return: The custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data3

    @custom_data3.setter
    def custom_data3(self, custom_data3):
        # type: (string_types) -> None
        """Sets the custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 3

        :param custom_data3: The custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data3 is not None:
            if not isinstance(custom_data3, string_types):
                raise TypeError("Invalid type for `custom_data3`, type has to be `string_types`")

        self._custom_data3 = custom_data3

    @property
    def custom_data4(self):
        # type: () -> string_types
        """Gets the custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 4

        :return: The custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data4

    @custom_data4.setter
    def custom_data4(self, custom_data4):
        # type: (string_types) -> None
        """Sets the custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 4

        :param custom_data4: The custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data4 is not None:
            if not isinstance(custom_data4, string_types):
                raise TypeError("Invalid type for `custom_data4`, type has to be `string_types`")

        self._custom_data4 = custom_data4

    @property
    def custom_data5(self):
        # type: () -> string_types
        """Gets the custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 5

        :return: The custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data5

    @custom_data5.setter
    def custom_data5(self, custom_data5):
        # type: (string_types) -> None
        """Sets the custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.

        Custom Data 5

        :param custom_data5: The custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data5 is not None:
            if not isinstance(custom_data5, string_types):
                raise TypeError("Invalid type for `custom_data5`, type has to be `string_types`")

        self._custom_data5 = custom_data5

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicenseCustomDataFieldLabels):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.vp8_video_configuration import Vp8VideoConfiguration
from bitmovin_api_sdk.encoding.configurations.video.vp8.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.vp8.vp8_video_configuration_list_query_params import Vp8VideoConfigurationListQueryParams


class Vp8Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Vp8Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, vp8_video_configuration, **kwargs):
        # type: (Vp8VideoConfiguration, dict) -> Vp8VideoConfiguration
        """Create VP8 Codec Configuration

        :param vp8_video_configuration: The VP8 Codec Configuration to be created
        :type vp8_video_configuration: Vp8VideoConfiguration, required
        :return: VP8 video configuration
        :rtype: Vp8VideoConfiguration
        """

        return self.api_client.post(
            '/encoding/configurations/video/vp8',
            vp8_video_configuration,
            type=Vp8VideoConfiguration,
            **kwargs
        )

    def delete(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete VP8 Codec Configuration

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: Id of the codec configuration
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/configurations/video/vp8/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> Vp8VideoConfiguration
        """VP8 Codec Configuration Details

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: VP8 video configuration
        :rtype: Vp8VideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/vp8/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=Vp8VideoConfiguration,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (Vp8VideoConfigurationListQueryParams, dict) -> Vp8VideoConfiguration
        """get_encoding_configurations_video_vp8

        :param query_params: Query parameters
        :type query_params: Vp8VideoConfigurationListQueryParams
        :return: List of VP8 codec configurations
        :rtype: Vp8VideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/vp8',
            query_params=query_params,
            pagination_response=True,
            type=Vp8VideoConfiguration,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.abstract_condition import AbstractCondition
from bitmovin_api_sdk.models.email_notification import EmailNotification
import pprint
import six


class EmailNotificationWithStreamConditions(EmailNotification):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 resolve=None,
                 resource_id=None,
                 triggered_at=None,
                 type_=None,
                 event_type=None,
                 category=None,
                 resource_type=None,
                 muted=None,
                 emails=None,
                 conditions=None):
        # type: (string_types, bool, string_types, datetime, string_types, string_types, string_types, string_types, bool, list[string_types], AbstractCondition) -> None
        super(EmailNotificationWithStreamConditions, self).__init__(id_=id_, resolve=resolve, resource_id=resource_id, triggered_at=triggered_at, type_=type_, event_type=event_type, category=category, resource_type=resource_type, muted=muted, emails=emails)

        self._conditions = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(EmailNotificationWithStreamConditions, self), 'openapi_types'):
            types = getattr(super(EmailNotificationWithStreamConditions, self), 'openapi_types')

        types.update({
            'conditions': 'AbstractCondition'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(EmailNotificationWithStreamConditions, self), 'attribute_map'):
            attributes = getattr(super(EmailNotificationWithStreamConditions, self), 'attribute_map')

        attributes.update({
            'conditions': 'conditions'
        })
        return attributes

    @property
    def conditions(self):
        # type: () -> AbstractCondition
        """Gets the conditions of this EmailNotificationWithStreamConditions.


        :return: The conditions of this EmailNotificationWithStreamConditions.
        :rtype: AbstractCondition
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        # type: (AbstractCondition) -> None
        """Sets the conditions of this EmailNotificationWithStreamConditions.


        :param conditions: The conditions of this EmailNotificationWithStreamConditions.
        :type: AbstractCondition
        """

        if conditions is not None:
            if not isinstance(conditions, AbstractCondition):
                raise TypeError("Invalid type for `conditions`, type has to be `AbstractCondition`")

        self._conditions = conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(EmailNotificationWithStreamConditions, self), "to_dict"):
            result = super(EmailNotificationWithStreamConditions, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailNotificationWithStreamConditions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Av1AdaptiveQuantMode(Enum):
    OFF = "OFF"
    VARIANCE = "VARIANCE"
    COMPLEXITY = "COMPLEXITY"
    CYCLIC_REFRESH = "CYCLIC_REFRESH"
    DELTA_QUANT = "DELTA_QUANT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PaddingDurationUnit(Enum):
    SECONDS = "SECONDS"
    FRAMES = "FRAMES"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_license_custom_data_field_labels import AnalyticsLicenseCustomDataFieldLabels
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class AnalyticsLicense(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 license_key=None,
                 created_at=None,
                 max_impressions=None,
                 impressions=None,
                 domains=None,
                 ignore_dnt=None,
                 time_zone=None,
                 custom_data_field_labels=None):
        # type: (string_types, string_types, string_types, datetime, int, int, list[AnalyticsLicenseDomain], bool, string_types, AnalyticsLicenseCustomDataFieldLabels) -> None
        super(AnalyticsLicense, self).__init__(id_=id_)

        self._name = None
        self._license_key = None
        self._created_at = None
        self._max_impressions = None
        self._impressions = None
        self._domains = list()
        self._ignore_dnt = None
        self._time_zone = None
        self._custom_data_field_labels = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if license_key is not None:
            self.license_key = license_key
        if created_at is not None:
            self.created_at = created_at
        if max_impressions is not None:
            self.max_impressions = max_impressions
        if impressions is not None:
            self.impressions = impressions
        if domains is not None:
            self.domains = domains
        if ignore_dnt is not None:
            self.ignore_dnt = ignore_dnt
        if time_zone is not None:
            self.time_zone = time_zone
        if custom_data_field_labels is not None:
            self.custom_data_field_labels = custom_data_field_labels

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AnalyticsLicense, self), 'openapi_types'):
            types = getattr(super(AnalyticsLicense, self), 'openapi_types')

        types.update({
            'name': 'string_types',
            'license_key': 'string_types',
            'created_at': 'datetime',
            'max_impressions': 'int',
            'impressions': 'int',
            'domains': 'list[AnalyticsLicenseDomain]',
            'ignore_dnt': 'bool',
            'time_zone': 'string_types',
            'custom_data_field_labels': 'AnalyticsLicenseCustomDataFieldLabels'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AnalyticsLicense, self), 'attribute_map'):
            attributes = getattr(super(AnalyticsLicense, self), 'attribute_map')

        attributes.update({
            'name': 'name',
            'license_key': 'licenseKey',
            'created_at': 'createdAt',
            'max_impressions': 'maxImpressions',
            'impressions': 'impressions',
            'domains': 'domains',
            'ignore_dnt': 'ignoreDNT',
            'time_zone': 'timeZone',
            'custom_data_field_labels': 'customDataFieldLabels'
        })
        return attributes

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsLicense.

        Name of the Analytics License

        :return: The name of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsLicense.

        Name of the Analytics License

        :param name: The name of this AnalyticsLicense.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AnalyticsLicense.

        License Key

        :return: The license_key of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AnalyticsLicense.

        License Key

        :param license_key: The license_key of this AnalyticsLicense.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this AnalyticsLicense.

        Creation date of the Analytics License in UTC format

        :return: The created_at of this AnalyticsLicense.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this AnalyticsLicense.

        Creation date of the Analytics License in UTC format

        :param created_at: The created_at of this AnalyticsLicense.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def max_impressions(self):
        # type: () -> int
        """Gets the max_impressions of this AnalyticsLicense.

        Maximum number of impressions

        :return: The max_impressions of this AnalyticsLicense.
        :rtype: int
        """
        return self._max_impressions

    @max_impressions.setter
    def max_impressions(self, max_impressions):
        # type: (int) -> None
        """Sets the max_impressions of this AnalyticsLicense.

        Maximum number of impressions

        :param max_impressions: The max_impressions of this AnalyticsLicense.
        :type: int
        """

        if max_impressions is not None:
            if not isinstance(max_impressions, int):
                raise TypeError("Invalid type for `max_impressions`, type has to be `int`")

        self._max_impressions = max_impressions

    @property
    def impressions(self):
        # type: () -> int
        """Gets the impressions of this AnalyticsLicense.

        Number of impressions recorded

        :return: The impressions of this AnalyticsLicense.
        :rtype: int
        """
        return self._impressions

    @impressions.setter
    def impressions(self, impressions):
        # type: (int) -> None
        """Sets the impressions of this AnalyticsLicense.

        Number of impressions recorded

        :param impressions: The impressions of this AnalyticsLicense.
        :type: int
        """

        if impressions is not None:
            if not isinstance(impressions, int):
                raise TypeError("Invalid type for `impressions`, type has to be `int`")

        self._impressions = impressions

    @property
    def domains(self):
        # type: () -> list[AnalyticsLicenseDomain]
        """Gets the domains of this AnalyticsLicense.

        Whitelisted domains

        :return: The domains of this AnalyticsLicense.
        :rtype: list[AnalyticsLicenseDomain]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        # type: (list) -> None
        """Sets the domains of this AnalyticsLicense.

        Whitelisted domains

        :param domains: The domains of this AnalyticsLicense.
        :type: list[AnalyticsLicenseDomain]
        """

        if domains is not None:
            if not isinstance(domains, list):
                raise TypeError("Invalid type for `domains`, type has to be `list[AnalyticsLicenseDomain]`")

        self._domains = domains

    @property
    def ignore_dnt(self):
        # type: () -> bool
        """Gets the ignore_dnt of this AnalyticsLicense.

        Whether the Do Not Track request from the browser should be ignored

        :return: The ignore_dnt of this AnalyticsLicense.
        :rtype: bool
        """
        return self._ignore_dnt

    @ignore_dnt.setter
    def ignore_dnt(self, ignore_dnt):
        # type: (bool) -> None
        """Sets the ignore_dnt of this AnalyticsLicense.

        Whether the Do Not Track request from the browser should be ignored

        :param ignore_dnt: The ignore_dnt of this AnalyticsLicense.
        :type: bool
        """

        if ignore_dnt is not None:
            if not isinstance(ignore_dnt, bool):
                raise TypeError("Invalid type for `ignore_dnt`, type has to be `bool`")

        self._ignore_dnt = ignore_dnt

    @property
    def time_zone(self):
        # type: () -> string_types
        """Gets the time_zone of this AnalyticsLicense.

        The timezone of the Analytics License

        :return: The time_zone of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        # type: (string_types) -> None
        """Sets the time_zone of this AnalyticsLicense.

        The timezone of the Analytics License

        :param time_zone: The time_zone of this AnalyticsLicense.
        :type: string_types
        """

        if time_zone is not None:
            if not isinstance(time_zone, string_types):
                raise TypeError("Invalid type for `time_zone`, type has to be `string_types`")

        self._time_zone = time_zone

    @property
    def custom_data_field_labels(self):
        # type: () -> AnalyticsLicenseCustomDataFieldLabels
        """Gets the custom_data_field_labels of this AnalyticsLicense.

        Labels for CustomData fields

        :return: The custom_data_field_labels of this AnalyticsLicense.
        :rtype: AnalyticsLicenseCustomDataFieldLabels
        """
        return self._custom_data_field_labels

    @custom_data_field_labels.setter
    def custom_data_field_labels(self, custom_data_field_labels):
        # type: (AnalyticsLicenseCustomDataFieldLabels) -> None
        """Sets the custom_data_field_labels of this AnalyticsLicense.

        Labels for CustomData fields

        :param custom_data_field_labels: The custom_data_field_labels of this AnalyticsLicense.
        :type: AnalyticsLicenseCustomDataFieldLabels
        """

        if custom_data_field_labels is not None:
            if not isinstance(custom_data_field_labels, AnalyticsLicenseCustomDataFieldLabels):
                raise TypeError("Invalid type for `custom_data_field_labels`, type has to be `AnalyticsLicenseCustomDataFieldLabels`")

        self._custom_data_field_labels = custom_data_field_labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AnalyticsLicense, self), "to_dict"):
            result = super(AnalyticsLicense, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.machine_learning.machine_learning_api import MachineLearningApi
from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.object_detection_api import ObjectDetectionApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Av1KeyPlacementMode(Enum):
    AUTO = "AUTO"
    FIXED = "FIXED"
    DISABLED = "DISABLED"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.daily_statistics import DailyStatistics
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.statistics.daily.daily_statistics_list_query_params import DailyStatisticsListQueryParams
from bitmovin_api_sdk.encoding.statistics.daily.daily_statistics_list_by_date_range_query_params import DailyStatisticsListByDateRangeQueryParams


class DailyApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DailyApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (DailyStatisticsListQueryParams, dict) -> DailyStatistics
        """List Daily Statistics

        :param query_params: Query parameters
        :type query_params: DailyStatisticsListQueryParams
        :return: List daily statistics
        :rtype: DailyStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/daily',
            query_params=query_params,
            pagination_response=True,
            type=DailyStatistics,
            **kwargs
        )

    def list_by_date_range(self, from_, to, query_params=None, **kwargs):
        # type: (date, date, DailyStatisticsListByDateRangeQueryParams, dict) -> DailyStatistics
        """List daily statistics within specific dates

        :param from_: Start date, format: yyyy-MM-dd
        :type from_: date, required
        :param to: End date, format: yyyy-MM-dd
        :type to: date, required
        :param query_params: Query parameters
        :type query_params: DailyStatisticsListByDateRangeQueryParams
        :return: List daily statistics
        :rtype: DailyStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/daily/{from}/{to}',
            path_params={'from': from_, 'to': to},
            query_params=query_params,
            pagination_response=True,
            type=DailyStatistics,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.input_type_response import InputTypeResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class TypeApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TypeApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> InputTypeResponse
        """Get Input Type

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Service specific result
        :rtype: InputTypeResponse
        """

        return self.api_client.get(
            '/encoding/inputs/{input_id}/type',
            path_params={'input_id': input_id},
            type=InputTypeResponse,
            **kwargs
        )
